import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:instagram_clone/models/menu.dart';

import 'package:instagram_clone/screens/post_screen.dart';
import 'package:instagram_clone/screens/profile_screen.dart';
import 'package:instagram_clone/screens/search_screen.dart';
import 'package:instagram_clone/screens/video_screen.dart';
import 'package:instagram_clone/utils/rive_utils.dart';
import 'package:instagram_clone/utils/text_utils.dart';
import 'package:instagram_clone/widgets/btn_bottom_navigator.dart';

import 'home_screen.dart';

class MainScreen extends StatefulWidget {
  const MainScreen({super.key});

  @override
  State<MainScreen> createState() => _MainScreenState();
}

class _MainScreenState extends State<MainScreen> {
  Menu selectedNavItem = menu_list.first;
  int index = 0;
  final TextUtils _textUtils = TextUtils();
  final PageController pageController = PageController(
          initialPage: 1,
        );

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      body: getScreen(),
      bottomNavigationBar: bottomBarRiveWidget(),
    );
  }
  Widget bottomBarRiveWidget(){
    return SafeArea(
      child: Container(
        padding: const EdgeInsets.all(12),
        margin: const EdgeInsets.all(24),
        decoration: BoxDecoration(
          color: Colors.black.withOpacity(0.8),
          borderRadius: const BorderRadius.all(Radius.circular(24)),
          boxShadow: [
              BoxShadow(
              color: Colors.black.withOpacity(0.3),
              offset: const Offset(0, 20),
              blurRadius: 20,
            ),
          ]
    
          ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            ...List.generate(menu_list.length, (index) => 
              BtnNavButton(
                menu: menu_list[index], 
                onTap: () {

                  RiveUtils.changeSMIBoolState(menu_list[index].rive.status!);
                  updateNavBtn(index, menu_list[index]);
                }, 
                riveOnInit: (artboard) {
                  menu_list[index].rive.status = RiveUtils.getRiveInput(
                    artboard, 
                    stateMachineName: menu_list[index].rive.stateMachineName,
                  );
                }, 
                activeMenu: selectedNavItem,
              ),
            ),

            InkWell(
            onTap: () {
              index = 4;
              setState(() {
                
              });
            },
            child: CircleAvatar(
              backgroundColor: index == 4 ? Colors.black : Colors.white,
              radius: 17,
              child: const CircleAvatar(
                radius: 15,
                backgroundImage: AssetImage("assets/avaters/Avatar 1.jpg"),
              ), 
              ),
          ),

          ],
        ),
      ),
    );
  }

  void updateNavBtn(int newIndex, Menu newNavBtn){
    setState(() {
      index = newIndex;
      selectedNavItem = newNavBtn;
    });
  }

  Widget bottomBarWidget() {
    return Container(
      padding: const EdgeInsets.all(15),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          InkWell(
            onTap: () {
              index = 0;
              setState(() {
                
              });
            },
            child: Image.asset(
              index == 0 ? "assets/icons/home_filled.png" : "assets/icons/home.png",
              width: 25,
              height: 25,
              color: Colors.black,
              ),
          ),
          InkWell(
            onTap: () {
              index = 1;
              setState(() {
                
              });
            },
            child: Image.asset(
              index == 1 ? "assets/icons/search_filled.png" : "assets/icons/search.png",
              width: 25,
              height: 25,
              color: Colors.black,
              ),
          ),
          InkWell(
            onTap: () {
              index = 2;
              Navigator.of(context).push(
                MaterialPageRoute(builder: (context) => const PostScreen())
              );
            },
            child: const Icon(
              Icons.plus_one_outlined,
              color: Colors.black,
              size: 25,
              ),
          ),
          InkWell(
            onTap: () {
              index = 3;
              setState(() {
                
              });
            },
            child: Icon(
              index == 3 ? CupertinoIcons.videocam_circle : CupertinoIcons.videocam_circle_fill,
              color: Colors.black,
              size: 25,
            ),
          ),
          InkWell(
            onTap: () {
              index = 4;
              setState(() {
                
              });
            },
            child: CircleAvatar(
              backgroundColor: index == 4 ? Colors.black : Colors.white,
              radius: 17,
              child: const CircleAvatar(
                radius: 15,
                backgroundImage: AssetImage("assets/avaters/Avatar 1.jpg"),
              ), 
              ),
          ),

        ],
      ),
    );
  }
  Widget getScreen() {
    switch (index) {
      case 0:
        return PageView(
          controller: pageController,
          children: const [
            PostScreen(),
            HomeScreen(),
            ProfileScreen(),
          ],
      );

      case 1:
        return const SearchScreen();

      case 2:
        return const HomeScreen();

      case 3:
        return const VideoScreen();

      case 4:
        return const ProfileScreen();

      default:
        return Container(); 
    }
  }
}

