import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/placeholder.dart';
import 'package:flutter/src/widgets/framework.dart';

import '../widgets/cube_widget.dart';

typedef CubeWidgetBuilder = CubeWidget Function(
    BuildContext context, int index, double pageNotifier);

class CubePageView extends StatefulWidget {
  
  // called whenever the page in the center of the viewport changes
  final ValueChanged<int>? onPageChanged;

  final PageController? controller;

  //build to customize your items
  final CubeWidgetBuilder? itemBuilder;

  // the number of item
  final int? itemCount;

  final List<Widget>? children;

  const CubePageView({
    super.key,
    this.onPageChanged,
    this.controller,
    required this.children
    }) :
     itemBuilder = null,
     itemCount = null,
     assert(children!=null)
     ;

  const CubePageView.builder({
    super.key,
    required this.itemCount,
    required this.itemBuilder,
    this.onPageChanged,
    this.controller,
  }) : children = null;  

  @override
  State<CubePageView> createState() => _CubePageViewState();


}

class _CubePageViewState extends State<CubePageView> {
  
  final _pageNotifier = ValueNotifier(0.0);
  late PageController _pageController;

  void _listener() {
    _pageNotifier.value = _pageController.page!;
  }


  @override
  void initState() {
    // TODO: implement initState
    _pageController = widget.controller ?? PageController();
    WidgetsBinding.instance.addPostFrameCallback(
      (timeStamp) { 
        _pageController.addListener(_listener);
      });
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    _pageController.removeListener(_listener);
    _pageController.dispose();
    _pageNotifier.dispose();
    super.dispose();
  }


  @override
  Widget build(BuildContext context) {
    return Material(
      color: Colors.transparent,
      child: Center(
        child: ValueListenableBuilder<double>(
          valueListenable: _pageNotifier,
          builder: (_, value, child) => PageView.builder(
            controller: _pageController,
            onPageChanged: widget.onPageChanged,
            physics: const BouncingScrollPhysics(),
            itemCount: widget.itemCount ?? widget.children?.length,
            itemBuilder: (_, index) {
              if (widget.itemBuilder != null) {
                return widget.itemBuilder!(context, index, value);
              }
              return CubeWidget(
                index: index, 
                pageNotifier: value,
                child: widget.children![index]);
            }
            ),
          ),
      ),
    );
  }
}



