import 'dart:math';
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter/src/widgets/placeholder.dart';

class CubeWidget extends StatefulWidget {
  
  // index of current item
  final int index;

  //pgate notifier value
  final double pageNotifier;

  final Widget child;
  
  const CubeWidget({
    super.key,
    required this.index,
    required this.pageNotifier,
    required this.child});

  @override
  State<CubeWidget> createState() => _CubeWidgetState();
}

class _CubeWidgetState extends State<CubeWidget> {


  @override
  Widget build(BuildContext context) {
    final isLeaving = (widget.index - widget.pageNotifier) <= 0;
    final t = (widget.index - widget.pageNotifier);
    final rotationY = lerpDouble(0, 90, t);
    final opacity = lerpDouble(0, 1, t.abs())?.clamp(0.0, 1.0);
    final transform = Matrix4.identity();
    transform.setEntry(3, 2, 0.003);
    transform.rotateY(-(degToRad(rotationY as num) as double));
    return Transform(
      alignment: isLeaving ? Alignment.centerRight : Alignment.centerLeft,
      transform: transform,
      child: Stack(
        children: [
          Positioned.fill(
            child: Opacity(
              opacity: opacity as double,
              child: Container(
                child: Container(
                  color: Colors.black87,
                ),
              ), 
              ),
          ),
          widget.child,
          
        ],
      ),);
  }

  num degToRad(num deg) => deg * (pi / 180.0);

  num radToDeg(num rad) => rad * (180.0 / pi);
}